@@ -18,6 +18,7 @@ Security group rules interface (1.1 extension).
 """
 
 from novaclient import base
+from novaclient import exceptions
 
 
 class SecurityGroupRule(base.Resource):
@@ -28,13 +29,13 @@ class SecurityGroupRule(base.Resource):
         self.manager.delete(self)
 
 
-class SecurityGroupRuleManager(base.ManagerWithFind):
+class SecurityGroupRuleManager(base.Manager):
     resource_class = SecurityGroupRule
 
     def create(self, parent_group_id, ip_protocol=None, from_port=None,
                to_port=None, cidr=None, group_id=None):
         """
-        Create a security group
+        Create a security group rule
 
         :param ip_protocol: IP protocol, one of 'tcp', 'udp' or 'icmp'
         :param from_port: Source port
@@ -43,6 +44,19 @@ class SecurityGroupRuleManager(base.ManagerWithFind):
         :param group_id: Security group id (int)
         :param parent_group_id: Parent security group id (int)
         """
+
+        try:
+            from_port = int(from_port)
+        except (TypeError, ValueError):
+            raise exceptions.CommandError("From port must be an integer.")
+        try:
+            to_port = int(to_port)
+        except (TypeError, ValueError):
+            raise exceptions.CommandError("To port must be an integer.")
+        if ip_protocol.upper() not in ['TCP', 'UDP', 'ICMP']:
+            raise exceptions.CommandError("Ip protocol must be 'tcp', 'udp', "
+                                          "or 'icmp'.")
+
         body = {"security_group_rule": {
                     "ip_protocol": ip_protocol,
                     "from_port": from_port,
